/**
* Rotary encoder
*/

#include "mbed.h"
#include "encoder.h"

/**
* Constructor
*
* pin_inA - pin where is input A of encoder connected
* pin_inB - pin where is input B of encoder connected
* slits - number of slits on a disc
*/
Encoder::Encoder(PinName pin_inA, PinName pin_inB, int slits) : _inA(pin_inA), _inB(pin_inB){
    this->slits = slits;
    
    encoder_rpm = 0;
    counter = 0;
    
    // pull-ups for mechanical encoder
    _inA.mode(PullUp);
    _inB.mode(PullUp);
    
    _inA.rise(callback(this, &Encoder::encoder_irq));
    
    tim1.reset();
    tim1.start();
}


/**
 * IRQ of encoder: Update counter when is rising edge on inA
 */
void Encoder::encoder_irq(void) {
    tim1.stop();
    
    if(_inB == 1){
        counter++;
        time = tim1.read();
    }
    else{
        counter--;
        time = -1.0f * tim1.read();
    }
    
    encoder_rpm = 60.0f/(time*slits);
    
    tim1.reset();
    tim1.start();
}


/**
 * Return actual value of rpm
 *
 * @return rpm of encoder
 */
float Encoder::get_rpm(void) {
    return encoder_rpm;
}


/**
 * Return actual value of counter
 *
 * @return pulse count
 */
int Encoder::get_count(void) {
    return counter;
}
