/**
* Rotary encoder
*/

/*************************************
********** Example of using **********
**************************************/
/*
#include "mbed.h"
#include "encoder.h"

//Encoder decleration
Encoder enc(PA_0, PA_1, 20);


//UART
Serial uart(USBTX, USBRX);


int main() {
    uart.printf("\n\rRotary encoder\n\r");
    uart.printf("^^^^^^^^^^^^^^\n\r\n\r");
    uart.printf("Encoder speed: %6.1f rpm\n\r", enc.get_rpm());
    uart.printf("Encoder steps: %6d\n\r", enc.get_count());

    while(1){
        uart.printf("\033[2A");
        uart.printf("Encoder speed: %6.1f rpm\n\r", enc.get_rpm());
        uart.printf("Encoder steps: %6d\n\r", enc.get_count());
        
        wait(1);
    }
}
*/

#ifndef ENCODER_H
#define ENCODER_H

#include "mbed.h"

class Encoder {
   public:
      float get_rpm();
      int get_count();
      
      Encoder(PinName pin_inA, PinName pin_inB, int slits);
 
   private:
      Timer tim1;
      float time;
      
      int slits;
      
      int counter;
      float encoder_rpm;
      
      InterruptIn _inA;          //Encoder - input A
      DigitalIn _inB;            //Encoder - input B
      
      void encoder_irq();
};

#endif /* ENCODER_H */